library(shiny)

## read in the data
cooler <- read.csv("CoolerReduced.csv", stringsAsFactors=FALSE)
#print(head(cooler))

## create the UI - the visual layout of the app
ui <- fluidPage(titlePanel("My STAT850 Shiny app", "Cooler Data"),
                h4("Analyzing the Performance of Different Types of", 
                   "Coolers and Coolants to Improve Cold Chain Transportation"), 
                br(),
                p("The purpose of this", strong("Shiny"), 
                  "app is to perform and display the analysis of the cooler",
                  "data obtained from Lowe et al."),
                sidebarLayout(
                  sidebarPanel(
                    selectInput(inputId="coolertype", label="Cooler Type", 
                                choices=c("Injection_molded", "Rotomolded", "PS_foam"),
                                selected=NULL)
                  ),
                  mainPanel(
                    tabsetPanel(
                      tabPanel("Model", 
                               textOutput("estmodel"), 
                               br(),
                               textOutput("rsquared")), 
                      tabPanel("Plot", 
                               plotOutput("fitplot")),
                      tabPanel("Table", 
                               tableOutput("predictions"))
                    )
                  )
                )
)

## print the background HTML for the UI
#print(ui)

## create the server - the logic for the app
server <- function(input, output){
  subset <- reactive({
    cooler[cooler$cooler_type == input$coolertype,]
  })
  
  # observe({
  #   print(subset())
  # })
  
  modfit <- reactive({
    lm(formula = time ~ water_bottles, 
       data = subset())
  })
  
  sumfit <- reactive({
    summary(modfit())
  })
  
  output$estmodel <- renderText({
    HTML(paste0("The estimated linear regression model for ",
                input$coolertype,
                " coolers is estimated time = ", 
                format(round(sumfit()$coefficients[1,1], 2), nsmall=2), " + ",
                format(round(sumfit()$coefficients[2,1], 2), nsmall=2), "water_bottles."))
  })
  
  output$rsquared <- renderText({
    HTML(paste0("The r-squared value is ",
                format(round(sumfit()$r.squared, 2), nsmall=2), 
                " and the adjusted r-squared value is ", 
                format(round(sumfit()$adj.r.squared, 2), nsmall=2), "."))
  })
  
  output$fitplot <- renderPlot({
    plot(x = subset()$water_bottles, 
         y = subset()$time, 
         xlab = "Water bottles", ylab = "Time", 
         main = "Time vs. Water bottles", 
         xlim = c(min(subset()$water_bottles), max(subset()$water_bottles)), 
         ylim = c(0, max(ceiling(subset()$time/10)*10)*1.1), 
         col = "red", pch = 1, cex = 1, lwd = 2, 
         panel.first = grid())
    curve(expr = predict(object = modfit(), newdata = data.frame(water_bottles = x)), 
          col = "blue", add = TRUE, lwd = 2, 
          xlim = c(min(subset()$water_bottles), max(subset()$water_bottles)))
    curve(expr = predict(object = modfit(), newdata = data.frame(water_bottles = x), 
                         interval = "prediction", level = 0.95)[,2], 
          col = "blue", add = TRUE, lwd = 2, lty = "dashed",
          xlim = c(min(subset()$water_bottles), max(subset()$water_bottles)))
    curve(expr = predict(object = modfit(), newdata = data.frame(water_bottles = x), 
                         interval = "prediction", level = 0.95)[,3], 
          col = "blue", add = TRUE, lwd = 2, lty = "dashed",
          xlim = c(min(subset()$water_bottles), max(subset()$water_bottles)))
  })
  
  output$predictions <- renderTable({
    data.frame(water_bottles = min(subset()$water_bottles):max(subset()$water_bottles), 
               round(predict(object = modfit(), 
                             newdata = data.frame(water_bottles = min(subset()$water_bottles):max(subset()$water_bottles)), 
                             interval = "prediction", levels = 0.95), 2))
  })
}

## combine the UI and server
shinyApp(ui = ui, server = server)